[commit] r2588 - branches/GME-449/SDK/DecoratorLib

GMESRC Repository Notifications gme-commit at list.isis.vanderbilt.edu
Wed Feb 18 09:56:20 CST 2015


Author: lattmann
Date: Wed Feb 18 09:56:19 2015
New Revision: 2588

Log:
GME-449 support .tiff for atom, set, and references.

Modified:
   branches/GME-449/SDK/DecoratorLib/DecoratorUtil.cpp

Modified: branches/GME-449/SDK/DecoratorLib/DecoratorUtil.cpp
==============================================================================
--- branches/GME-449/SDK/DecoratorLib/DecoratorUtil.cpp	Wed Feb 18 09:49:50 2015	(r2587)
+++ branches/GME-449/SDK/DecoratorLib/DecoratorUtil.cpp	Wed Feb 18 09:56:19 2015	(r2588)
@@ -609,11 +609,11 @@
 	if ( strName.GetLength() >= 4 ) {
 		strExt = strName.Right( 4 ).MakeLower();
 	
-		if( strName.GetLength() >= 5) // in case of ".jpeg"
+		if( strName.GetLength() >= 5) // in case of ".jpeg" and ".tiff"
 			strEx2 = strName.Right(5).MakeLower();
 		
 		if ( strExt != _T(".bmp") && strExt != _T(".gif") && strExt != _T(".png")
-			&& strExt != _T(".jpg") && strExt != _T(".jpe") && strEx2 != _T(".jpeg")
+			&& strExt != _T(".jpg") && strExt != _T(".jpe") && strEx2 != _T(".jpeg") && strEx2 != _T(".tiff")
 			&& strExt != _T(".res")  && strExt != _T(".wmf") && strExt != _T(".emf"))
 			strExt = _T("");
 	}
@@ -621,7 +621,7 @@
 	if( strExt.IsEmpty()) // if no extension then try the different formats
 	{
 		bool success = false;
-		static TCHAR * exts[] = { _T(".bmp"), _T(".gif"), _T(".png"), _T(".jpg"), _T(".jpe"), _T(".jpeg"), _T(".wmf"), _T(".emf") };
+		static TCHAR * exts[] = { _T(".bmp"), _T(".gif"), _T(".png"), _T(".jpg"), _T(".jpe"), _T(".jpeg"), _T(".tiff"), _T(".wmf"), _T(".emf") };
 		for( int i = 0; !success && i < 6; ++i)
 		{
 			CString strName2 = strName + exts[i];


More information about the gme-commit mailing list